@@ -104,7 +104,6 @@ class JackTripWorker : public QObject
     int getID() { return mID; }
 
     void setBufferStrategy(int BufferStrategy) { mBufferStrategy = BufferStrategy; }
-    void setRegulatorThread(QThread* ptr) { mRegulatorThreadPtr = ptr; }
     void setNetIssuesSimulation(double loss, double jitter, double delay_rel)
     {
         mSimulatedLossRate   = loss;
@@ -176,14 +175,13 @@ class JackTripWorker : public QObject
 
     int mID = 0;  ///< ID thread number
 
-    int mBufferStrategy          = 1;
-    int mBroadcastQueue          = 0;
-    double mSimulatedLossRate    = 0.0;
-    double mSimulatedJitterRate  = 0.0;
-    double mSimulatedDelayRel    = 0.0;
-    bool mUseRtUdpPriority       = false;
-    int mIOStatTimeout           = 0;
-    QThread* mRegulatorThreadPtr = NULL;
+    int mBufferStrategy         = 1;
+    int mBroadcastQueue         = 0;
+    double mSimulatedLossRate   = 0.0;
+    double mSimulatedJitterRate = 0.0;
+    double mSimulatedDelayRel   = 0.0;
+    bool mUseRtUdpPriority      = false;
+    int mIOStatTimeout          = 0;
 
     QSharedPointer<std::ostream> mIOStatStream;
 #ifdef WAIR                   // wair
