@@ -104,7 +104,7 @@ constexpr double AutoInitValFactor =
 // tweak
 constexpr int WindowDivisor = 8;  // for faster auto tracking
 constexpr double AutoHeadroomGlitchTolerance =
-    0.02;  // Acceptable rate of skips before auto headroom is increased (2.0%)
+    0.01;  // Acceptable rate of skips before auto headroom is increased (1.0%)
 constexpr double AutoHistoryWindow =
     60;  // rolling window of time (in seconds) over which auto tolerance roughly adjusts
 constexpr double AutoSmoothingFactor =
@@ -307,17 +307,20 @@ Regulator::Regulator(int rcvChannels, int bit_res, int localFPP, int qLen, int b
 
 Regulator::~Regulator()
 {
-    delete[] mXfrBuffer;
-    delete[] mBroadcastBuffer;
-    delete[] mSlotBuf;
-    delete pushStat;
-    delete pullStat;
-    for (int i = 0; i < mNumChannels; i++)
-        delete mChanData[i];
+    if (mInitialized) {
+        delete[] mXfrBuffer;
+        delete[] mBroadcastBuffer;
+        delete[] mSlotBuf;
+        delete[] mSlots;
+        delete pushStat;
+        delete pullStat;
+        delete mTime;
+        delete ba;
+        for (int i = 0; i < mNumChannels; i++)
+            delete mChanData[i];
+    }
     if (m_b_BroadcastRingBuffer)
         delete m_b_BroadcastRingBuffer;
-    delete mTime;
-    delete ba;
     if (mWorkerThreadPtr != nullptr) {
         mWorkerThreadPtr->quit();
         mWorkerThreadPtr->wait();
@@ -474,15 +477,26 @@ void Regulator::updateTolerance(int glitches, int skipped)
     if (mAutoHeadroom < 0) {
         // variable headroom: automatically increase to minimize glitch counts
         // only increase headroom if doing so would have reduced the number of
-        // glitches that occured over the past two seconds by 2% or more.
+        // glitches that occured over the past second by 1% or more.
         // prevent headroom from growing beyond rolling average of max.
-        const int skipsAllowed =
-            static_cast<int>(AutoHeadroomGlitchTolerance * mSampleRate / mPeerFPP);
+        int skipsAllowed;
+        if (mMsecTolerance >= (mPeerFPPdurMsec * 2)) {
+            // calculate skips allowed if tolerance if above or equal to duration of two
+            // packets
+            skipsAllowed =
+                static_cast<int>(AutoHeadroomGlitchTolerance * mSampleRate / mPeerFPP);
+        } else {
+            // zero skips allowed if tolerance is below duration of two packets
+            skipsAllowed = 0;
+            // also don't require two intervals in a row (override)
+            mSkipAutoHeadroom = false;
+        }
         if (glitches > 0 && skipped > skipsAllowed
             && mCurrentHeadroom + 1 <= pushStat->longTermMax) {
             if (mSkipAutoHeadroom) {
                 mSkipAutoHeadroom = false;
             } else {
+                // don't increase headroom two intervals in a row
                 mSkipAutoHeadroom = true;
                 ++mCurrentHeadroom;
                 cout << "PLC glitches=" << glitches << " skipped=" << skipped << ">"
@@ -490,6 +504,7 @@ void Regulator::updateTolerance(int glitches, int skipped)
                      << " (max=" << pushStat->longTermMax << ")" << endl;
             }
         } else {
+            // thresholds not met: require 2 intervals in a row
             mSkipAutoHeadroom = true;
         }
     } else {
@@ -536,7 +551,16 @@ void Regulator::updatePushStats(int seq_num)
         mLastSkipped            = totalSkipped;
         if (mAuto && pushStat->lastTime > AutoInitDur) {
             // after AutoInitDur: update auto tolerance once per second
-            updateTolerance(newGlitches, newSkipped);
+            if (pushStat->lastTime <= (AutoInitDur + 3000)) {
+                // Ignore glitches and skips for the first 3 seconds after
+                // we have switched from using the startup tolerance to
+                // a calculated tolerance. Otherwise, the switch can
+                // sometimes cause it to bump headroom prematurely even
+                // though there are no real audio glitches.
+                updateTolerance(0, 0);
+            } else {
+                updateTolerance(newGlitches, newSkipped);
+            }
         }
     }
 }
@@ -560,7 +584,11 @@ bool Regulator::pullPacket()
     const int lastSeqNumIn = mLastSeqNumIn.load(std::memory_order_acquire);
     int skipped            = 0;
 
-    if ((lastSeqNumIn == -1) || (!mInitialized)) {
+    if ((lastSeqNumIn == -1) || (!mInitialized) || (now < mMsecTolerance)) {
+        // return silence during startup:
+        // * no packets arrived yet
+        // * not initialized
+        // * hasn't run long enough to meet tolerance
         goto ZERO_OUTPUT;
     } else if (lastSeqNumIn == mLastSeqNumOut) {
         goto UNDERRUN;
@@ -588,7 +616,8 @@ bool Regulator::pullPacket()
                 if (skipped < 0)
                     skipped += NumSlots;
             }
-            if (mIncomingTiming[next] + mMsecTolerance >= now) {
+            // check if packet's age matches tolerance, or is the best candidate we have
+            if (mIncomingTiming[next] + mMsecTolerance >= now || i == 0) {
                 // next is the best candidate
                 memcpy(mXfrBuffer, mSlots[next], mPeerBytes);
                 mLastSeqNumOut = next;
